@@ -30,32 +30,32 @@ class TaasAgentApi(object):
         self.client = n_rpc.get_client(target)
 
     def create_tap_service(self, context, tap_service_msg, host):
-        LOG.debug("In RPC Call for Create Tap Service: Host=%s, MSG=%s" %
-                  (host, tap_service_msg))
+        LOG.debug("In RPC Call for Create Tap Service: Host=%s, MSG=%s",
+                  host, tap_service_msg)
 
         cctxt = self.client.prepare(fanout=True)
         cctxt.cast(context, 'create_tap_service',
                    tap_service_msg=tap_service_msg, host=host)
 
     def create_tap_flow(self, context, tap_flow_msg, host):
-        LOG.debug("In RPC Call for Create Tap Flow: Host=%s, MSG=%s" %
-                  (host, tap_flow_msg))
+        LOG.debug("In RPC Call for Create Tap Flow: Host=%s, MSG=%s",
+                  host, tap_flow_msg)
 
         cctxt = self.client.prepare(fanout=True)
         cctxt.cast(context, 'create_tap_flow', tap_flow_msg=tap_flow_msg,
                    host=host)
 
     def delete_tap_service(self, context, tap_service_msg, host):
-        LOG.debug("In RPC Call for Delete Tap Service: Host=%s, MSG=%s" %
-                  (host, tap_service_msg))
+        LOG.debug("In RPC Call for Delete Tap Service: Host=%s, MSG=%s",
+                  host, tap_service_msg)
 
         cctxt = self.client.prepare(fanout=True)
         cctxt.cast(context, 'delete_tap_service',
                    tap_service_msg=tap_service_msg, host=host)
 
     def delete_tap_flow(self, context, tap_flow_msg, host):
-        LOG.debug("In RPC Call for Delete Tap Flow: Host=%s, MSG=%s" %
-                  (host, tap_flow_msg))
+        LOG.debug("In RPC Call for Delete Tap Flow: Host=%s, MSG=%s",
+                  host, tap_flow_msg)
 
         cctxt = self.client.prepare(fanout=True)
         cctxt.cast(context, 'delete_tap_flow', tap_flow_msg=tap_flow_msg,
